@@ -110,6 +110,8 @@ def good_credentials(env):
     res = {keys[i].lower(): values[i] for i in range(len(keys))}
     if "USER_NAME" in env.keys():
         res["username"] = env["USER_NAME"]
+    if "CODE" in env.keys():
+        res["code"] = None
     return res
 
 
